@@ -1,6 +1,7 @@
 module Puppet::Parser::Functions
+  # @return Windows native path
   newfunction(:windows_native_path, arity: 1, type: :rvalue, doc: <<-EOS
-  Return a windows native path
+  @return Return a windows native path
   EOS
   ) do |args|
     path = args[0]
